This package data set provides the results of applying the
stm::estimateEffect() function to the included biodiv_model_K10 topic
model object.
This package data set provides the results of applying the
stm::estimateEffect() function to the included biodiv_model_K10 topic
model object.