Skip to contents

This package data set provides a sample STM topic model with K = 10 topics (see stm::stm()). The model has been fit to bioRxiv and medRxiv preprints from 2017 to 2021 that contain the term 'biodiversity' in the title or abstract. The model has been fit with the respective publication status and publication year as topic prevalence covariates. The included biodiv_effect_K10 dataset captures the regression parameters of these document covariates.

Usage

biodiv_model_K10

Format

An STM topic model object