This package data set provides the results of applying the
stm::estimateEffect() function to the included covid_model_K20 topic
model object.
This package data set provides the results of applying the
stm::estimateEffect() function to the included covid_model_K20 topic
model object.