Skip to contents

This package data set provides a sample STM topic model with K = 20 topics (see stm::stm()). The model has been fit to bioRxiv and medRxiv preprints from 2020 to 2023 that contain the terms 'sars-cov' or 'covid' in the title or abstract. The model has been fit with the respective preprint server and publication year as topic prevalence covariates. The included covid_effect_K20 dataset captures the regression parameters of these document covariates.

Usage

covid_model_K20

Format

An STM topic model object