Skip to contents

This is a convenience dataset to include the results of evaluating topic models with different topic numbers (K) for thematic subsets of the bioRxiv and medRxiv preprints. Scripts to run the actual evaluations are included in the package repo.

Usage

topicmodel_evaluations

Format

A dataframe with four variables

Details

The dataset specifies the preprint subset, used K, type of evaluation metric and the value of that metric.