This is a convenience dataset to include the results of evaluating topic models with different topic numbers (K) for thematic subsets of the bioRxiv and medRxiv preprints. Scripts to run the actual evaluations are included in the package repo.
This is a convenience dataset to include the results of evaluating topic models with different topic numbers (K) for thematic subsets of the bioRxiv and medRxiv preprints. Scripts to run the actual evaluations are included in the package repo.